Option Explicit On 
Option Strict On

Namespace VB21.Day03

    Module Invest

        Private dblAnnualInterest As Double = 0
        Private iYears As Integer = 0
        Private decStartingBalance As Decimal = 0
        Private decMonthlyDeposit As Decimal = 0

        Public Sub Main()
            Dim decResult As Decimal

            'get input values
            GetInputValues()

            'calculate 
            decResult = CalculateFV(dblAnnualInterest, iYears, decMonthlyDeposit, decStartingBalance)

            'output result
            DisplayResults(decResult)

        End Sub

        Private Function CalculateFV(ByVal AnnualInterest As Double, ByVal Years As Integer, ByVal MonthlyDeposit As Decimal, ByVal StartingBalance As Decimal) As Decimal
            'divide by 1200 to make it percent and per month
            Dim decMonthlyInterest As Decimal = CDec(AnnualInterest / 1200)
            Dim iMonths As Integer = Years * 12
            Dim decTemp As Decimal
            Dim decReturn As Decimal

            'The formula for Future Value (FV) is:
            'FV = MonthlyDeposit * (((1 + MonthlyInterest)^Months - 1 ) / MonthlyInterest ) 
            '   +  StartingBalance * ( 1 + MonthlyInterest )^Months

            'we'll need this value in a couple of places
            decTemp = CDec((1 + decMonthlyInterest) ^ iMonths)
            decReturn = CDec(MonthlyDeposit * ((decTemp - 1) / decMonthlyInterest) + (StartingBalance * decTemp))

            Return decReturn

        End Function

        Private Sub GetInputValues()
            Console.WriteLine()
            decStartingBalance = CDec(GetValue("Initial Balance: "))
            dblAnnualInterest = CDbl(GetValue("Annual Interest (e.g. for 5%, enter 5): "))
            decMonthlyDeposit = CDec(GetValue("Monthly deposit: "))
            iYears = CInt(GetValue("Years of investment: "))
            Console.WriteLine()
        End Sub

        Private Function GetValue(ByVal Prompt As String) As String

            Console.Write(Prompt)
            Return Console.ReadLine

        End Function

        Private Sub DisplayResults(ByVal Result As Decimal)
            Console.WriteLine()

            Console.WriteLine("If you start with {0:c}, ", decStartingBalance)
            Console.WriteLine("       and invest {0:c} per month", decMonthlyDeposit)
            Console.WriteLine("              for {0} years", iYears)
            Console.WriteLine("               at {0}% interest.", dblAnnualInterest)

            Console.WriteLine()
            Console.WriteLine("Your final balance would be: {0:c}", Result)

        End Sub

    End Module

End Namespace
